[jboss-svn-commits] JBL Code SVN: r12825 - in labs/jbossesb/trunk/product: services/soap and 4 other directories.

jboss-svn-commits at lists.jboss.org jboss-svn-commits at lists.jboss.org
Mon Jun 25 09:24:38 EDT 2007


Author: tfennelly
Date: 2007-06-25 09:24:38 -0400 (Mon, 25 Jun 2007)
New Revision: 12825

Added:
   labs/jbossesb/trunk/product/services/soap/jaxb-bindings.xjb
Modified:
   labs/jbossesb/trunk/product/samples/quickstarts/webservice_bpel/jaxb-intros-customerOrder.xml
   labs/jbossesb/trunk/product/samples/quickstarts/webservice_bpel/jaxb-intros-shippingRequest.xml
   labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/IntroductionsAnnotationReader.java
   labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/configmodel/ClassIntroConfig.java
   labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/configmodel/ClassMemberIntroConfig.java
   labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/configmodel/FieldIntroConfig.java
   labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/configmodel/JaxbIntros.java
   labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/configmodel/MethodIntroConfig.java
   labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/configmodel/ObjectFactory.java
   labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/configmodel/XmlAttributeIntro.java
   labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/configmodel/XmlElementIntro.java
   labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/configmodel/XmlTypeIntro.java
   labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/configmodel/package-info.java
   labs/jbossesb/trunk/product/services/soap/src/main/resources/jaxb-intros.xsd
   labs/jbossesb/trunk/product/services/soap/src/test/java/org/jboss/soa/esb/actions/soap/jaxbintro/IntroductionsConfigParserUnitTest.java
   labs/jbossesb/trunk/product/services/soap/src/test/java/org/jboss/soa/esb/actions/soap/jaxbintro/intro-config-01.xml
   labs/jbossesb/trunk/product/services/soap/src/test/java/org/jboss/soa/esb/actions/soap/jaxbintro/intro-config-02.xml
   labs/jbossesb/trunk/product/services/soap/src/test/java/org/jboss/soa/esb/actions/soap/jaxbintro/intro-config-03.xml
Log:
Updated the JAXB introductions config - make it more readable.

Modified: labs/jbossesb/trunk/product/samples/quickstarts/webservice_bpel/jaxb-intros-customerOrder.xml
===================================================================
--- labs/jbossesb/trunk/product/samples/quickstarts/webservice_bpel/jaxb-intros-customerOrder.xml	2007-06-25 11:52:21 UTC (rev 12824)
+++ labs/jbossesb/trunk/product/samples/quickstarts/webservice_bpel/jaxb-intros-customerOrder.xml	2007-06-25 13:24:38 UTC (rev 12825)
@@ -9,20 +9,20 @@
     <!--
     The type namespaces on the customerOrder are different from the rest of the message...
     -->
-    <class-intro-config name="com.activebpel.ordermanagement.CustomerOrder">
-        <method-intro-config name="get.*">
-            <XmlElementIntro namespace="http://org.jboss.esb/quickstarts/bpel/ABI_OrderManager" />
-        </method-intro-config>
-    </class-intro-config>
+    <Class name="com.activebpel.ordermanagement.CustomerOrder">
+        <Method name="get.*">
+            <XmlElement namespace="http://org.jboss.esb/quickstarts/bpel/ABI_OrderManager" />
+        </Method>
+    </Class>
 
     <!--
     More general namespace config for the rest of the message...
     -->
-    <class-intro-config name="com.activebpel.ordermanagement.*">
-        <method-intro-config name="get.*">
-            <XmlElementIntro namespace="http://ordermanagement.activebpel.com/jaws" />
-        </method-intro-config>
-    </class-intro-config>
+    <Class name="com.activebpel.ordermanagement.*">
+        <Method name="get.*">
+            <XmlElement namespace="http://ordermanagement.activebpel.com/jaws" />
+        </Method>
+    </Class>
 
     <!--
     The XSD for the schema can be found at:

Modified: labs/jbossesb/trunk/product/samples/quickstarts/webservice_bpel/jaxb-intros-shippingRequest.xml
===================================================================
--- labs/jbossesb/trunk/product/samples/quickstarts/webservice_bpel/jaxb-intros-shippingRequest.xml	2007-06-25 11:52:21 UTC (rev 12824)
+++ labs/jbossesb/trunk/product/samples/quickstarts/webservice_bpel/jaxb-intros-shippingRequest.xml	2007-06-25 13:24:38 UTC (rev 12825)
@@ -5,22 +5,22 @@
     JAXB annotation introductions for ShippingRequest messages.
     -->
 
-    <class-intro-config name="com.activebpel.shipping.ShippingRequest">
+    <Class name="com.activebpel.shipping.ShippingRequest">
         <!-- The order number is in the OrderManager namespace... -->
-        <method-intro-config name="getOrderNumber">
-            <XmlElementIntro namespace="http://org.jboss.esb/quickstarts/bpel/ABI_OrderManager" />
-        </method-intro-config>
+        <Method name="getOrderNumber">
+            <XmlElement namespace="http://org.jboss.esb/quickstarts/bpel/ABI_OrderManager" />
+        </Method>
         <!-- The rest are in the shipping namespace... -->
-        <method-intro-config name="get.*">
-            <XmlElementIntro namespace="http://org.jboss.esb/quickstarts/bpel/ABI_Shipping" />
-        </method-intro-config>
-    </class-intro-config>
+        <Method name="get.*">
+            <XmlElement namespace="http://org.jboss.esb/quickstarts/bpel/ABI_Shipping" />
+        </Method>
+    </Class>
 
-    <class-intro-config name="com.activebpel.shipping.ShippingResponse">
-        <method-intro-config name="isOrderShipped">
-            <XmlElementIntro namespace="http://org.jboss.esb/quickstarts/bpel/ABI_Shipping" />
-        </method-intro-config>
-    </class-intro-config>
+    <Class name="com.activebpel.shipping.ShippingResponse">
+        <Method name="isOrderShipped">
+            <XmlElement namespace="http://org.jboss.esb/quickstarts/bpel/ABI_Shipping" />
+        </Method>
+    </Class>
 
     <!--
     The XSD for the schema can be found at:

Added: labs/jbossesb/trunk/product/services/soap/jaxb-bindings.xjb
===================================================================
--- labs/jbossesb/trunk/product/services/soap/jaxb-bindings.xjb	                        (rev 0)
+++ labs/jbossesb/trunk/product/services/soap/jaxb-bindings.xjb	2007-06-25 13:24:38 UTC (rev 12825)
@@ -0,0 +1,43 @@
+<jxb:bindings version="1.0"
+              xmlns:jxb="http://java.sun.com/xml/ns/jaxb"
+              xmlns:xs="http://www.w3.org/2001/XMLSchema">
+
+    <jxb:bindings schemaLocation="src/main/resources/jaxb-intros.xsd" node="/xs:schema">
+        <jxb:schemaBindings>
+            <jxb:package name="org.jboss.soa.esb.actions.soap.jaxbintro.configmodel">
+            </jxb:package>
+        </jxb:schemaBindings>
+
+        <jxb:bindings node="//xs:complexType[@name='Class']">
+            <jxb:class name="ClassIntroConfig">
+            </jxb:class>
+        </jxb:bindings>
+
+        <jxb:bindings node="//xs:complexType[@name='Field']">
+            <jxb:class name="FieldIntroConfig">
+            </jxb:class>
+        </jxb:bindings>
+
+        <jxb:bindings node="//xs:complexType[@name='Method']">
+            <jxb:class name="MethodIntroConfig">
+            </jxb:class>
+        </jxb:bindings>
+
+        <jxb:bindings node="//xs:complexType[@name='XmlType']">
+            <jxb:class name="XmlTypeIntro">
+            </jxb:class>
+        </jxb:bindings>
+
+        <jxb:bindings node="//xs:complexType[@name='XmlElement']">
+            <jxb:class name="XmlElementIntro">
+            </jxb:class>
+        </jxb:bindings>
+
+        <jxb:bindings node="//xs:complexType[@name='XmlAttribute']">
+            <jxb:class name="XmlAttributeIntro">
+            </jxb:class>
+        </jxb:bindings>
+
+    </jxb:bindings>
+    
+</jxb:bindings>

Modified: labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/IntroductionsAnnotationReader.java
===================================================================
--- labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/IntroductionsAnnotationReader.java	2007-06-25 11:52:21 UTC (rev 12824)
+++ labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/IntroductionsAnnotationReader.java	2007-06-25 13:24:38 UTC (rev 12825)
@@ -99,7 +99,7 @@
             ClassIntroConfig classIntroConfig = getClassIntroConfig(clazz);
 
             if(classIntroConfig != null) {
-                XmlTypeIntro intro = classIntroConfig.getXmlTypeIntro();
+                XmlTypeIntro intro = classIntroConfig.getXmlType();
                 if(intro != null) {
                     return (A) XmlTypeHandler.createProxy(intro);
                 }
@@ -113,7 +113,7 @@
         if(annotationType == XmlType.class) {
             ClassIntroConfig classIntroConfig = getClassIntroConfig(clazz);
 
-            if(classIntroConfig != null && classIntroConfig.getXmlTypeIntro() != null) {
+            if(classIntroConfig != null && classIntroConfig.getXmlType() != null) {
                 return true;
             }
         }
@@ -146,7 +146,7 @@
         String className = clazz.getName();
         ClassIntroConfig globalIntro = null;
 
-        for(ClassIntroConfig classIntro : introductions.getClassIntroConfig()) {
+        for(ClassIntroConfig classIntro : introductions.getClazz()) {
             if(classIntro.getName().equals(className)) {
                 return classIntro;
             } else if(globalIntro == null && isRegexMatch(className, classIntro.getName())) {
@@ -164,7 +164,7 @@
         if(classIntroConfig != null) {
             String fieldName = field.getName();
 
-            for(FieldIntroConfig fieldIntro : classIntroConfig.getFieldIntroConfig()) {
+            for(FieldIntroConfig fieldIntro : classIntroConfig.getField()) {
                 if(fieldIntro.getName().equals(fieldName)) {
                     return fieldIntro;
                 } else if(globalIntro == null && isRegexMatch(fieldName, fieldIntro.getName())) {
@@ -183,7 +183,7 @@
         if(classIntroConfig != null) {
             String methodName = method.getName();
 
-            for(MethodIntroConfig methodIntro : classIntroConfig.getMethodIntroConfig()) {
+            for(MethodIntroConfig methodIntro : classIntroConfig.getMethod()) {
                 if(methodIntro.getName().equals(methodName)) {
                     return methodIntro;
                 } else if(globalIntro == null && isRegexMatch(methodName, methodIntro.getName())) {
@@ -216,12 +216,12 @@
         Annotation proxy = null;
 
         if(annotation == javax.xml.bind.annotation.XmlAttribute.class) {
-            XmlAttributeIntro xmlAttributeIntro = memberIntroConfig.getXmlAttributeIntro();
+            XmlAttributeIntro xmlAttributeIntro = memberIntroConfig.getXmlAttribute();
             if(xmlAttributeIntro != null) {
                 proxy = XmlAttributeHandler.createProxy(xmlAttributeIntro);
             }
         } else if(annotation == javax.xml.bind.annotation.XmlElement.class) {
-            XmlElementIntro xmlElementIntro = memberIntroConfig.getXmlElementIntro();
+            XmlElementIntro xmlElementIntro = memberIntroConfig.getXmlElement();
             if(xmlElementIntro != null) {
                 proxy = XmlElementHandler.createProxy(xmlElementIntro);
             }
@@ -230,13 +230,11 @@
         return proxy;
     }
 
-    private boolean isMemberAnnotationIntroAvailable(Class annotation, ClassMemberIntroConfig memberIntroConfig) {
-        Annotation proxy = null;
-
+    private boolean isMemberAnnotationIntroAvailable(Class<? extends Annotation> annotation, ClassMemberIntroConfig memberIntroConfig) {
         if(annotation == javax.xml.bind.annotation.XmlAttribute.class) {
-            return (memberIntroConfig.getXmlAttributeIntro() != null);
+            return (memberIntroConfig.getXmlAttribute() != null);
         } else if(annotation == javax.xml.bind.annotation.XmlElement.class) {
-            return (memberIntroConfig.getXmlElementIntro() != null);
+            return (memberIntroConfig.getXmlElement() != null);
         }
 
         return false;
@@ -247,7 +245,7 @@
         List<Annotation> annotations = new ArrayList<Annotation>();
 
         for( int i = 0; i < r.length; i++ ) {
-            Class annType = r[i].getClass();
+            Class<? extends Object> annType = r[i].getClass();
             if(annType == XmlAttribute.class || annType == XmlElement.class) {
                 // We'll handle these explicitly (below)!!
                 continue;

Modified: labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/configmodel/ClassIntroConfig.java
===================================================================
--- labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/configmodel/ClassIntroConfig.java	2007-06-25 11:52:21 UTC (rev 12824)
+++ labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/configmodel/ClassIntroConfig.java	2007-06-25 13:24:38 UTC (rev 12825)
@@ -2,7 +2,7 @@
 // This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, v2.1.3-b01-fcs 
 // See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
 // Any modifications to this file will be lost upon recompilation of the source schema. 
-// Generated on: 2007.06.14 at 03:00:46 PM BST 
+// Generated on: 2007.06.25 at 01:32:14 PM BST 
 //
 
 
@@ -14,24 +14,23 @@
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlAttribute;
 import javax.xml.bind.annotation.XmlElement;
-import javax.xml.bind.annotation.XmlRootElement;
 import javax.xml.bind.annotation.XmlSchemaType;
 import javax.xml.bind.annotation.XmlType;
 
 
 /**
- * <p>Java class for anonymous complex type.
+ * <p>Java class for Class complex type.
  * 
  * <p>The following schema fragment specifies the expected content contained within this class.
  * 
  * <pre>
- * &lt;complexType>
+ * &lt;complexType name="Class">
  *   &lt;complexContent>
  *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
  *       &lt;sequence>
- *         &lt;element ref="{http://jbossesb.jboss.com/xsd/jaxb-intros}XmlTypeIntro" minOccurs="0"/>
- *         &lt;element ref="{http://jbossesb.jboss.com/xsd/jaxb-intros}field-intro-config" maxOccurs="unbounded" minOccurs="0"/>
- *         &lt;element ref="{http://jbossesb.jboss.com/xsd/jaxb-intros}method-intro-config" maxOccurs="unbounded" minOccurs="0"/>
+ *         &lt;element ref="{http://jbossesb.jboss.com/xsd/jaxb-intros}XmlType" minOccurs="0"/>
+ *         &lt;element ref="{http://jbossesb.jboss.com/xsd/jaxb-intros}Field" maxOccurs="unbounded" minOccurs="0"/>
+ *         &lt;element ref="{http://jbossesb.jboss.com/xsd/jaxb-intros}Method" maxOccurs="unbounded" minOccurs="0"/>
  *       &lt;/sequence>
  *       &lt;attribute name="name" use="required" type="{http://www.w3.org/2001/XMLSchema}anySimpleType" />
  *     &lt;/restriction>
@@ -42,61 +41,60 @@
  * 
  */
 @XmlAccessorType(XmlAccessType.FIELD)
- at XmlType(name = "", propOrder = {
-    "xmlTypeIntro",
-    "fieldIntroConfig",
-    "methodIntroConfig"
+ at XmlType(name = "Class", propOrder = {
+    "xmlType",
+    "field",
+    "method"
 })
- at XmlRootElement(name = "class-intro-config")
 public class ClassIntroConfig {
 
-    @XmlElement(name = "XmlTypeIntro")
-    protected XmlTypeIntro xmlTypeIntro;
-    @XmlElement(name = "field-intro-config")
-    protected List<FieldIntroConfig> fieldIntroConfig;
-    @XmlElement(name = "method-intro-config")
-    protected List<MethodIntroConfig> methodIntroConfig;
+    @XmlElement(name = "XmlType")
+    protected XmlTypeIntro xmlType;
+    @XmlElement(name = "Field")
+    protected List<FieldIntroConfig> field;
+    @XmlElement(name = "Method")
+    protected List<MethodIntroConfig> method;
     @XmlAttribute(required = true)
     @XmlSchemaType(name = "anySimpleType")
     protected String name;
 
     /**
-     * Gets the value of the xmlTypeIntro property.
+     * Gets the value of the xmlType property.
      * 
      * @return
      *     possible object is
      *     {@link XmlTypeIntro }
      *     
      */
-    public XmlTypeIntro getXmlTypeIntro() {
-        return xmlTypeIntro;
+    public XmlTypeIntro getXmlType() {
+        return xmlType;
     }
 
     /**
-     * Sets the value of the xmlTypeIntro property.
+     * Sets the value of the xmlType property.
      * 
      * @param value
      *     allowed object is
      *     {@link XmlTypeIntro }
      *     
      */
-    public void setXmlTypeIntro(XmlTypeIntro value) {
-        this.xmlTypeIntro = value;
+    public void setXmlType(XmlTypeIntro value) {
+        this.xmlType = value;
     }
 
     /**
-     * Gets the value of the fieldIntroConfig property.
+     * Gets the value of the field property.
      * 
      * <p>
      * This accessor method returns a reference to the live list,
      * not a snapshot. Therefore any modification you make to the
      * returned list will be present inside the JAXB object.
-     * This is why there is not a <CODE>set</CODE> method for the fieldIntroConfig property.
+     * This is why there is not a <CODE>set</CODE> method for the field property.
      * 
      * <p>
      * For example, to add a new item, do as follows:
      * <pre>
-     *    getFieldIntroConfig().add(newItem);
+     *    getField().add(newItem);
      * </pre>
      * 
      * 
@@ -106,26 +104,26 @@
      * 
      * 
      */
-    public List<FieldIntroConfig> getFieldIntroConfig() {
-        if (fieldIntroConfig == null) {
-            fieldIntroConfig = new ArrayList<FieldIntroConfig>();
+    public List<FieldIntroConfig> getField() {
+        if (field == null) {
+            field = new ArrayList<FieldIntroConfig>();
         }
-        return this.fieldIntroConfig;
+        return this.field;
     }
 
     /**
-     * Gets the value of the methodIntroConfig property.
+     * Gets the value of the method property.
      * 
      * <p>
      * This accessor method returns a reference to the live list,
      * not a snapshot. Therefore any modification you make to the
      * returned list will be present inside the JAXB object.
-     * This is why there is not a <CODE>set</CODE> method for the methodIntroConfig property.
+     * This is why there is not a <CODE>set</CODE> method for the method property.
      * 
      * <p>
      * For example, to add a new item, do as follows:
      * <pre>
-     *    getMethodIntroConfig().add(newItem);
+     *    getMethod().add(newItem);
      * </pre>
      * 
      * 
@@ -135,11 +133,11 @@
      * 
      * 
      */
-    public List<MethodIntroConfig> getMethodIntroConfig() {
-        if (methodIntroConfig == null) {
-            methodIntroConfig = new ArrayList<MethodIntroConfig>();
+    public List<MethodIntroConfig> getMethod() {
+        if (method == null) {
+            method = new ArrayList<MethodIntroConfig>();
         }
-        return this.methodIntroConfig;
+        return this.method;
     }
 
     /**

Modified: labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/configmodel/ClassMemberIntroConfig.java
===================================================================
--- labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/configmodel/ObjectFactory.java	2007-06-25 11:52:21 UTC (rev 12824)
+++ labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/configmodel/ObjectFactory.java	2007-06-25 13:24:38 UTC (rev 12825)
@@ -2,7 +2,7 @@
 // This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, v2.1.3-b01-fcs 
 // See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
 // Any modifications to this file will be lost upon recompilation of the source schema. 
-// Generated on: 2007.06.14 at 03:00:46 PM BST 
+// Generated on: 2007.06.25 at 01:32:14 PM BST 
 //
 
 
@@ -31,9 +31,13 @@
 @XmlRegistry
 public class ObjectFactory {
 
-    private final static QName _MethodIntroConfig_QNAME = new QName("http://jbossesb.jboss.com/xsd/jaxb-intros", "method-intro-config");
-    private final static QName _FieldIntroConfig_QNAME = new QName("http://jbossesb.jboss.com/xsd/jaxb-intros", "field-intro-config");
+    private final static QName _XmlType_QNAME = new QName("http://jbossesb.jboss.com/xsd/jaxb-intros", "XmlType");
+    private final static QName _XmlElement_QNAME = new QName("http://jbossesb.jboss.com/xsd/jaxb-intros", "XmlElement");
+    private final static QName _Field_QNAME = new QName("http://jbossesb.jboss.com/xsd/jaxb-intros", "Field");
+    private final static QName _Method_QNAME = new QName("http://jbossesb.jboss.com/xsd/jaxb-intros", "Method");
     private final static QName _ClassMemberIntroConfig_QNAME = new QName("http://jbossesb.jboss.com/xsd/jaxb-intros", "class-member-intro-config");
+    private final static QName _XmlAttribute_QNAME = new QName("http://jbossesb.jboss.com/xsd/jaxb-intros", "XmlAttribute");
+    private final static QName _Class_QNAME = new QName("http://jbossesb.jboss.com/xsd/jaxb-intros", "Class");
 
     /**
      * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.jboss.soa.esb.actions.soap.jaxbintro.configmodel
@@ -43,6 +47,14 @@
     }
 
     /**
+     * Create an instance of {@link XmlAttributeIntro }
+     * 
+     */
+    public XmlAttributeIntro createXmlAttributeIntro() {
+        return new XmlAttributeIntro();
+    }
+
+    /**
      * Create an instance of {@link ClassMemberIntroConfig }
      * 
      */
@@ -51,14 +63,30 @@
     }
 
     /**
-     * Create an instance of {@link JaxbIntros }
+     * Create an instance of {@link FieldIntroConfig }
      * 
      */
-    public JaxbIntros createJaxbIntros() {
-        return new JaxbIntros();
+    public FieldIntroConfig createFieldIntroConfig() {
+        return new FieldIntroConfig();
     }
 
     /**
+     * Create an instance of {@link XmlTypeIntro }
+     * 
+     */
+    public XmlTypeIntro createXmlTypeIntro() {
+        return new XmlTypeIntro();
+    }
+
+    /**
+     * Create an instance of {@link MethodIntroConfig }
+     * 
+     */
+    public MethodIntroConfig createMethodIntroConfig() {
+        return new MethodIntroConfig();
+    }
+
+    /**
      * Create an instance of {@link XmlElementIntro }
      * 
      */
@@ -75,62 +103,74 @@
     }
 
     /**
-     * Create an instance of {@link MethodIntroConfig }
+     * Create an instance of {@link JaxbIntros }
      * 
      */
-    public MethodIntroConfig createMethodIntroConfig() {
-        return new MethodIntroConfig();
+    public JaxbIntros createJaxbIntros() {
+        return new JaxbIntros();
     }
 
     /**
-     * Create an instance of {@link FieldIntroConfig }
+     * Create an instance of {@link JAXBElement }{@code <}{@link XmlTypeIntro }{@code >}}
      * 
      */
-    public FieldIntroConfig createFieldIntroConfig() {
-        return new FieldIntroConfig();
+    @XmlElementDecl(namespace = "http://jbossesb.jboss.com/xsd/jaxb-intros", name = "XmlType")
+    public JAXBElement<XmlTypeIntro> createXmlType(XmlTypeIntro value) {
+        return new JAXBElement<XmlTypeIntro>(_XmlType_QNAME, XmlTypeIntro.class, null, value);
     }
 
     /**
-     * Create an instance of {@link XmlAttributeIntro }
+     * Create an instance of {@link JAXBElement }{@code <}{@link XmlElementIntro }{@code >}}
      * 
      */
-    public XmlAttributeIntro createXmlAttributeIntro() {
-        return new XmlAttributeIntro();
+    @XmlElementDecl(namespace = "http://jbossesb.jboss.com/xsd/jaxb-intros", name = "XmlElement")
+    public JAXBElement<XmlElementIntro> createXmlElement(XmlElementIntro value) {
+        return new JAXBElement<XmlElementIntro>(_XmlElement_QNAME, XmlElementIntro.class, null, value);
     }
 
     /**
-     * Create an instance of {@link XmlTypeIntro }
+     * Create an instance of {@link JAXBElement }{@code <}{@link FieldIntroConfig }{@code >}}
      * 
      */
-    public XmlTypeIntro createXmlTypeIntro() {
-        return new XmlTypeIntro();
+    @XmlElementDecl(namespace = "http://jbossesb.jboss.com/xsd/jaxb-intros", name = "Field", substitutionHeadNamespace = "http://jbossesb.jboss.com/xsd/jaxb-intros", substitutionHeadName = "class-member-intro-config")
+    public JAXBElement<FieldIntroConfig> createField(FieldIntroConfig value) {
+        return new JAXBElement<FieldIntroConfig>(_Field_QNAME, FieldIntroConfig.class, null, value);
     }
 
     /**
      * Create an instance of {@link JAXBElement }{@code <}{@link MethodIntroConfig }{@code >}}
      * 
      */
-    @XmlElementDecl(namespace = "http://jbossesb.jboss.com/xsd/jaxb-intros", name = "method-intro-config", substitutionHeadNamespace = "http://jbossesb.jboss.com/xsd/jaxb-intros", substitutionHeadName = "class-member-intro-config")
-    public JAXBElement<MethodIntroConfig> createMethodIntroConfig(MethodIntroConfig value) {
-        return new JAXBElement<MethodIntroConfig>(_MethodIntroConfig_QNAME, MethodIntroConfig.class, null, value);
+    @XmlElementDecl(namespace = "http://jbossesb.jboss.com/xsd/jaxb-intros", name = "Method", substitutionHeadNamespace = "http://jbossesb.jboss.com/xsd/jaxb-intros", substitutionHeadName = "class-member-intro-config")
+    public JAXBElement<MethodIntroConfig> createMethod(MethodIntroConfig value) {
+        return new JAXBElement<MethodIntroConfig>(_Method_QNAME, MethodIntroConfig.class, null, value);
     }
 
     /**
-     * Create an instance of {@link JAXBElement }{@code <}{@link FieldIntroConfig }{@code >}}
+     * Create an instance of {@link JAXBElement }{@code <}{@link Object }{@code >}}
      * 
      */
-    @XmlElementDecl(namespace = "http://jbossesb.jboss.com/xsd/jaxb-intros", name = "field-intro-config", substitutionHeadNamespace = "http://jbossesb.jboss.com/xsd/jaxb-intros", substitutionHeadName = "class-member-intro-config")
-    public JAXBElement<FieldIntroConfig> createFieldIntroConfig(FieldIntroConfig value) {
-        return new JAXBElement<FieldIntroConfig>(_FieldIntroConfig_QNAME, FieldIntroConfig.class, null, value);
+    @XmlElementDecl(namespace = "http://jbossesb.jboss.com/xsd/jaxb-intros", name = "class-member-intro-config")
+    public JAXBElement<Object> createClassMemberIntroConfig(Object value) {
+        return new JAXBElement<Object>(_ClassMemberIntroConfig_QNAME, Object.class, null, value);
     }
 
     /**
-     * Create an instance of {@link JAXBElement }{@code <}{@link Object }{@code >}}
+     * Create an instance of {@link JAXBElement }{@code <}{@link XmlAttributeIntro }{@code >}}
      * 
      */
-    @XmlElementDecl(namespace = "http://jbossesb.jboss.com/xsd/jaxb-intros", name = "class-member-intro-config")
-    public JAXBElement<Object> createClassMemberIntroConfig(Object value) {
-        return new JAXBElement<Object>(_ClassMemberIntroConfig_QNAME, Object.class, null, value);
+    @XmlElementDecl(namespace = "http://jbossesb.jboss.com/xsd/jaxb-intros", name = "XmlAttribute")
+    public JAXBElement<XmlAttributeIntro> createXmlAttribute(XmlAttributeIntro value) {
+        return new JAXBElement<XmlAttributeIntro>(_XmlAttribute_QNAME, XmlAttributeIntro.class, null, value);
     }
 
+    /**
+     * Create an instance of {@link JAXBElement }{@code <}{@link ClassIntroConfig }{@code >}}
+     * 
+     */
+    @XmlElementDecl(namespace = "http://jbossesb.jboss.com/xsd/jaxb-intros", name = "Class")
+    public JAXBElement<ClassIntroConfig> createClass(ClassIntroConfig value) {
+        return new JAXBElement<ClassIntroConfig>(_Class_QNAME, ClassIntroConfig.class, null, value);
+    }
+
 }

Modified: labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/configmodel/XmlAttributeIntro.java
===================================================================
--- labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/configmodel/XmlTypeIntro.java	2007-06-25 11:52:21 UTC (rev 12824)
+++ labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/configmodel/XmlTypeIntro.java	2007-06-25 13:24:38 UTC (rev 12825)
@@ -2,7 +2,7 @@
 // This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, v2.1.3-b01-fcs 
 // See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
 // Any modifications to this file will be lost upon recompilation of the source schema. 
-// Generated on: 2007.06.14 at 03:00:46 PM BST 
+// Generated on: 2007.06.25 at 01:32:14 PM BST 
 //
 
 
@@ -11,18 +11,17 @@
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlAttribute;
-import javax.xml.bind.annotation.XmlRootElement;
 import javax.xml.bind.annotation.XmlSchemaType;
 import javax.xml.bind.annotation.XmlType;
 
 
 /**
- * <p>Java class for anonymous complex type.
+ * <p>Java class for XmlType complex type.
  * 
  * <p>The following schema fragment specifies the expected content contained within this class.
  * 
  * <pre>
- * &lt;complexType>
+ * &lt;complexType name="XmlType">
  *   &lt;complexContent>
  *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
  *       &lt;attribute name="name" type="{http://www.w3.org/2001/XMLSchema}anySimpleType" default="##default" />
@@ -38,8 +37,7 @@
  * 
  */
 @XmlAccessorType(XmlAccessType.FIELD)
- at XmlType(name = "")
- at XmlRootElement(name = "XmlTypeIntro")
+ at XmlType(name = "XmlType")
 public class XmlTypeIntro {
 
     @XmlAttribute

Modified: labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/configmodel/package-info.java
===================================================================
--- labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/configmodel/package-info.java	2007-06-25 11:52:21 UTC (rev 12824)
+++ labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/configmodel/package-info.java	2007-06-25 13:24:38 UTC (rev 12825)
@@ -2,7 +2,7 @@
 // This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, v2.1.3-b01-fcs 
 // See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
 // Any modifications to this file will be lost upon recompilation of the source schema. 
-// Generated on: 2007.06.14 at 03:00:46 PM BST 
+// Generated on: 2007.06.25 at 01:32:14 PM BST 
 //
 
 @javax.xml.bind.annotation.XmlSchema(namespace = "http://jbossesb.jboss.com/xsd/jaxb-intros", elementFormDefault = javax.xml.bind.annotation.XmlNsForm.QUALIFIED)

Modified: labs/jbossesb/trunk/product/services/soap/src/main/resources/jaxb-intros.xsd
===================================================================
--- labs/jbossesb/trunk/product/services/soap/src/main/resources/jaxb-intros.xsd	2007-06-25 11:52:21 UTC (rev 12824)
+++ labs/jbossesb/trunk/product/services/soap/src/main/resources/jaxb-intros.xsd	2007-06-25 13:24:38 UTC (rev 12825)
@@ -12,25 +12,25 @@
         </xsd:annotation>
         <xsd:complexType>
             <xsd:sequence>
-                <xsd:element ref="jaxb-intros:class-intro-config" minOccurs="1" maxOccurs="unbounded"/>
+                <xsd:element ref="jaxb-intros:Class" minOccurs="1" maxOccurs="unbounded"/>
             </xsd:sequence>
             <xsd:attribute name="default-namespace" use="optional"/>
         </xsd:complexType>
     </xsd:element>
 
-    <xsd:element name="class-intro-config">
+    <xsd:complexType name="Class">
+        <xsd:sequence>
+            <xsd:element ref="jaxb-intros:XmlType" minOccurs="0" maxOccurs="1"/>
+            <xsd:element ref="jaxb-intros:Field" minOccurs="0" maxOccurs="unbounded"/>
+            <xsd:element ref="jaxb-intros:Method" minOccurs="0" maxOccurs="unbounded"/>
+        </xsd:sequence>
+        <xsd:attribute name="name" use="required"/>
+    </xsd:complexType>
+    <xsd:element name="Class" type="jaxb-intros:Class">
         <xsd:annotation>
             <xsd:documentation xml:lang="en">Java Top Level Class JAXB Annotation Introductions configuration.
             </xsd:documentation>
         </xsd:annotation>
-        <xsd:complexType>
-            <xsd:sequence>
-                <xsd:element ref="jaxb-intros:XmlTypeIntro" minOccurs="0" maxOccurs="1"/>
-                <xsd:element ref="jaxb-intros:field-intro-config" minOccurs="0" maxOccurs="unbounded"/>
-                <xsd:element ref="jaxb-intros:method-intro-config" minOccurs="0" maxOccurs="unbounded"/>
-            </xsd:sequence>
-            <xsd:attribute name="name" use="required"/>
-        </xsd:complexType>
     </xsd:element>
 
     <xsd:complexType name="class-member-intro-config">
@@ -38,75 +38,75 @@
            <xsd:documentation xml:lang="en">Java Class Member (Field, Method Constructor) JAXB Annotation Introductions configuration base type.</xsd:documentation>
         </xsd:annotation>
         <xsd:sequence>
-            <xsd:element ref="jaxb-intros:XmlElementIntro" minOccurs="0" maxOccurs="1"/>
-            <xsd:element ref="jaxb-intros:XmlAttributeIntro" minOccurs="0" maxOccurs="1"/>
+            <xsd:element ref="jaxb-intros:XmlElement" minOccurs="0" maxOccurs="1"/>
+            <xsd:element ref="jaxb-intros:XmlAttribute" minOccurs="0" maxOccurs="1"/>
         </xsd:sequence>
         <xsd:attribute name="name" use="required"/>
     </xsd:complexType>
     <xsd:element name="class-member-intro-config" abstract="true" />
 
-    <xsd:element name="field-intro-config" substitutionGroup="jaxb-intros:class-member-intro-config">
+    <xsd:complexType name="Field">
+        <xsd:complexContent>
+            <xsd:extension base="jaxb-intros:class-member-intro-config" />
+        </xsd:complexContent>
+    </xsd:complexType>
+    <xsd:element name="Field" type="jaxb-intros:Field" substitutionGroup="jaxb-intros:class-member-intro-config">
         <xsd:annotation>
             <xsd:documentation xml:lang="en">Java Class Field JAXB Annotation Introductions configuration.
             </xsd:documentation>
         </xsd:annotation>
-        <xsd:complexType>
-            <xsd:complexContent>
-                <xsd:extension base="jaxb-intros:class-member-intro-config" />
-            </xsd:complexContent>
-        </xsd:complexType>
     </xsd:element>
 
-    <xsd:element name="method-intro-config" substitutionGroup="jaxb-intros:class-member-intro-config">
+    <xsd:complexType name="Method">
+        <xsd:complexContent>
+            <xsd:extension base="jaxb-intros:class-member-intro-config" />
+        </xsd:complexContent>
+    </xsd:complexType>
+    <xsd:element name="Method" type="jaxb-intros:Method" substitutionGroup="jaxb-intros:class-member-intro-config">
         <xsd:annotation>
             <xsd:documentation xml:lang="en">Java Class Method JAXB Annotation Introductions configuration.
             </xsd:documentation>
         </xsd:annotation>
-        <xsd:complexType>
-            <xsd:complexContent>
-                <xsd:extension base="jaxb-intros:class-member-intro-config" />
-            </xsd:complexContent>
-        </xsd:complexType>
     </xsd:element>
 
-    <xsd:element name="XmlTypeIntro">
+    <xsd:complexType name="XmlType">
+        <xsd:attribute name="name" use="optional" default="##default"/>
+        <xsd:attribute name="propOrder" use="optional" default=""/>
+        <xsd:attribute name="namespace" use="optional" default="##default"/>
+        <xsd:attribute name="factoryClass" use="optional"/>
+        <xsd:attribute name="factoryMethod" use="optional" default=""/>
+    </xsd:complexType>
+    <xsd:element name="XmlType" type="jaxb-intros:XmlType">
         <xsd:annotation>
             <xsd:documentation xml:lang="en">JAXB 'XmlType' Annotation Introduction configuration.</xsd:documentation>
         </xsd:annotation>
-        <xsd:complexType>
-            <xsd:attribute name="name" use="optional" default="##default"/>
-            <xsd:attribute name="propOrder" use="optional" default=""/>
-            <xsd:attribute name="namespace" use="optional" default="##default"/>
-            <xsd:attribute name="factoryClass" use="optional"/>
-            <xsd:attribute name="factoryMethod" use="optional" default=""/>
-        </xsd:complexType>
     </xsd:element>
 
-    <xsd:element name="XmlElementIntro">
+    <xsd:complexType name="XmlElement">
+        <xsd:attribute name="name" use="optional" default="##default"/>
+        <xsd:attribute name="nillable" type="xsd:boolean" use="optional" default="false"/>
+        <xsd:attribute name="required" type="xsd:boolean" use="optional" default="false"/>
+        <xsd:attribute name="namespace" use="optional" default="##default"/>
+        <xsd:attribute name="defaultValue" use="optional"/>
+        <xsd:attribute name="type" use="optional"/>
+    </xsd:complexType>
+    <xsd:element name="XmlElement" type="jaxb-intros:XmlElement">
         <xsd:annotation>
             <xsd:documentation xml:lang="en">JAXB 'XmlElement' Annotation Introduction configuration.
             </xsd:documentation>
         </xsd:annotation>
-        <xsd:complexType>
-            <xsd:attribute name="name" use="optional" default="##default"/>
-            <xsd:attribute name="nillable" type="xsd:boolean" use="optional" default="false"/>
-            <xsd:attribute name="required" type="xsd:boolean" use="optional" default="false"/>
-            <xsd:attribute name="namespace" use="optional" default="##default"/>
-            <xsd:attribute name="defaultValue" use="optional"/>
-            <xsd:attribute name="type" use="optional"/>
-        </xsd:complexType>
     </xsd:element>
 
-    <xsd:element name="XmlAttributeIntro">
+    <xsd:complexType name="XmlAttribute">
+        <xsd:attribute name="name" use="optional" default="##default"/>
+        <xsd:attribute name="required" type="xsd:boolean" use="optional" default="false"/>
+        <xsd:attribute name="namespace" use="optional" default="##default"/>
+    </xsd:complexType>
+    <xsd:element name="XmlAttribute" type="jaxb-intros:XmlAttribute">
         <xsd:annotation>
             <xsd:documentation xml:lang="en">JAXB 'XmlAttribute' Annotation Introduction configuration.
             </xsd:documentation>
         </xsd:annotation>
-        <xsd:complexType>
-            <xsd:attribute name="name" use="optional" default="##default"/>
-            <xsd:attribute name="required" type="xsd:boolean" use="optional" default="false"/>
-            <xsd:attribute name="namespace" use="optional" default="##default"/>
-        </xsd:complexType>
     </xsd:element>
 
 </xsd:schema>

Modified: labs/jbossesb/trunk/product/services/soap/src/test/java/org/jboss/soa/esb/actions/soap/jaxbintro/IntroductionsConfigParserUnitTest.java
===================================================================
--- labs/jbossesb/trunk/product/services/soap/src/test/java/org/jboss/soa/esb/actions/soap/jaxbintro/IntroductionsConfigParserUnitTest.java	2007-06-25 11:52:21 UTC (rev 12824)
+++ labs/jbossesb/trunk/product/services/soap/src/test/java/org/jboss/soa/esb/actions/soap/jaxbintro/IntroductionsConfigParserUnitTest.java	2007-06-25 13:24:38 UTC (rev 12825)
@@ -33,11 +33,11 @@
         JaxbIntros config = IntroductionsConfigParser.parseConfig(getClass().getResourceAsStream("intro-config-01.xml"));
 
         assertEquals("http://jbossesb.x.jboss.org", config.getDefaultNamespace());
-        assertEquals(2, config.getClassIntroConfig().size());
-        ClassIntroConfig classIntroConfig = config.getClassIntroConfig().get(0);
+        assertEquals(2, config.getClazz().size());
+        ClassIntroConfig classIntroConfig = config.getClazz().get(0);
         assertEquals(TestBean1.class.getName(), classIntroConfig.getName());
-        assertEquals("http://jbossesb.y.jboss.org", classIntroConfig.getXmlTypeIntro().getNamespace());
-        assertEquals(1, classIntroConfig.getMethodIntroConfig().size());
+        assertEquals("http://jbossesb.y.jboss.org", classIntroConfig.getXmlType().getNamespace());
+        assertEquals(1, classIntroConfig.getMethod().size());
 
         // Could add more tests here but we're OK for now... JAXB seems to be working fine and
         // we'll have more tests on the AnnotationReader!

Modified: labs/jbossesb/trunk/product/services/soap/src/test/java/org/jboss/soa/esb/actions/soap/jaxbintro/intro-config-01.xml
===================================================================
--- labs/jbossesb/trunk/product/services/soap/src/test/java/org/jboss/soa/esb/actions/soap/jaxbintro/intro-config-01.xml	2007-06-25 11:52:21 UTC (rev 12824)
+++ labs/jbossesb/trunk/product/services/soap/src/test/java/org/jboss/soa/esb/actions/soap/jaxbintro/intro-config-01.xml	2007-06-25 13:24:38 UTC (rev 12825)
@@ -8,17 +8,17 @@
     Register it against the http://jbossesb.jboss.com/xsd/jaxb-intros namespace in your IDE and away you go :-)
     -->
 
-    <class-intro-config name="org.jboss.soa.esb.actions.soap.jaxbintro.TestBean1">
-        <XmlTypeIntro namespace="http://jbossesb.y.jboss.org" />
-        <method-intro-config name="getOrderDate">
-            <XmlAttributeIntro namespace="http://jbossesb.z.jboss.org" required="false"/>
-        </method-intro-config>
-    </class-intro-config>
+    <Class name="org.jboss.soa.esb.actions.soap.jaxbintro.TestBean1">
+        <XmlType namespace="http://jbossesb.y.jboss.org" />
+        <Method name="getOrderDate">
+            <XmlAttribute namespace="http://jbossesb.z.jboss.org" required="false"/>
+        </Method>
+    </Class>
 
-    <class-intro-config name="org.jboss.soa.esb.actions.soap.jaxbintro.TestBean2">
-        <field-intro-config name="orderNumber">
-            <XmlElementIntro name="OrderNum" nillable="true" />
-        </field-intro-config>
-    </class-intro-config>
+    <Class name="org.jboss.soa.esb.actions.soap.jaxbintro.TestBean2">
+        <Field name="orderNumber">
+            <XmlElement name="OrderNum" nillable="true" />
+        </Field>
+    </Class>
 
 </jaxb-intros>

Modified: labs/jbossesb/trunk/product/services/soap/src/test/java/org/jboss/soa/esb/actions/soap/jaxbintro/intro-config-02.xml
===================================================================
--- labs/jbossesb/trunk/product/services/soap/src/test/java/org/jboss/soa/esb/actions/soap/jaxbintro/intro-config-02.xml	2007-06-25 11:52:21 UTC (rev 12824)
+++ labs/jbossesb/trunk/product/services/soap/src/test/java/org/jboss/soa/esb/actions/soap/jaxbintro/intro-config-02.xml	2007-06-25 13:24:38 UTC (rev 12825)
@@ -8,17 +8,17 @@
     Register it against the http://jbossesb.jboss.com/xsd/jaxb-intros namespace in your IDE and away you go :-)
     -->
 
-    <class-intro-config name="org.jboss.soa.esb.actions.soap.jaxbintro.TestBean1">
-        <XmlTypeIntro namespace="http://jbossesb.y.jboss.org" propOrder="a,b,c" factoryClass="org.jboss.soa.esb.actions.soap.jaxbintro.TestBean1" />        
-        <method-intro-config name="getOrderDate">
-            <XmlAttributeIntro namespace="http://jbossesb.z.jboss.org" required="false"/>
-        </method-intro-config>
-    </class-intro-config>
+    <Class name="org.jboss.soa.esb.actions.soap.jaxbintro.TestBean1">
+        <XmlType namespace="http://jbossesb.y.jboss.org" propOrder="a,b,c" factoryClass="org.jboss.soa.esb.actions.soap.jaxbintro.TestBean1" />
+        <Method name="getOrderDate">
+            <XmlAttribute namespace="http://jbossesb.z.jboss.org" required="false"/>
+        </Method>
+    </Class>
 
-    <class-intro-config name="org.jboss.soa.esb.actions.soap.jaxbintro.TestBean2">
-        <field-intro-config name="orderNumber">
-            <XmlElementIntro name="OrderNum" nillable="true" type="org.jboss.soa.esb.actions.soap.jaxbintro.TestBean2" />
-        </field-intro-config>
-    </class-intro-config>
+    <Class name="org.jboss.soa.esb.actions.soap.jaxbintro.TestBean2">
+        <Field name="orderNumber">
+            <XmlElement name="OrderNum" nillable="true" type="org.jboss.soa.esb.actions.soap.jaxbintro.TestBean2" />
+        </Field>
+    </Class>
 
 </jaxb-intros>

Modified: labs/jbossesb/trunk/product/services/soap/src/test/java/org/jboss/soa/esb/actions/soap/jaxbintro/intro-config-03.xml
===================================================================
--- labs/jbossesb/trunk/product/services/soap/src/test/java/org/jboss/soa/esb/actions/soap/jaxbintro/intro-config-03.xml	2007-06-25 11:52:21 UTC (rev 12824)
+++ labs/jbossesb/trunk/product/services/soap/src/test/java/org/jboss/soa/esb/actions/soap/jaxbintro/intro-config-03.xml	2007-06-25 13:24:38 UTC (rev 12825)
@@ -14,19 +14,19 @@
     <!--
     The type namespaces on the customerOrder are different from the rest of the message...     
     -->
-    <class-intro-config name="org.jboss.soa.esb.actions.soap.jaxbintro.testbeans.CustomerOrder">
-        <method-intro-config name="get.*">
-            <XmlElementIntro namespace="http://org.jboss.esb/ns" />
-        </method-intro-config>
-    </class-intro-config>
+    <Class name="org.jboss.soa.esb.actions.soap.jaxbintro.testbeans.CustomerOrder">
+        <Method name="get.*">
+            <XmlElement namespace="http://org.jboss.esb/ns" />
+        </Method>
+    </Class>
 
     <!--
     More general namespace config...
     -->
-    <class-intro-config name="org.jboss.soa.esb.actions.soap.jaxbintro.testbeans.*">
-        <method-intro-config name="get.*">
-            <XmlElementIntro namespace="http://org.jboss.esb/ns1" />
-        </method-intro-config>
-    </class-intro-config>
+    <Class name="org.jboss.soa.esb.actions.soap.jaxbintro.testbeans.*">
+        <Method name="get.*">
+            <XmlElement namespace="http://org.jboss.esb/ns1" />
+        </Method>
+    </Class>
 
 </jaxb-intros>




More information about the jboss-svn-commits mailing list
--- labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/configmodel/ClassMemberIntroConfig.java	2007-06-25 11:52:21 UTC (rev 12824)
+++ labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/configmodel/ClassMemberIntroConfig.java	2007-06-25 13:24:38 UTC (rev 12825)
@@ -2,7 +2,7 @@
 // This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, v2.1.3-b01-fcs 
 // See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
 // Any modifications to this file will be lost upon recompilation of the source schema. 
-// Generated on: 2007.06.14 at 03:00:46 PM BST 
+// Generated on: 2007.06.25 at 01:32:14 PM BST 
 //
 
 
@@ -29,8 +29,8 @@
  *   &lt;complexContent>
  *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
  *       &lt;sequence>
- *         &lt;element ref="{http://jbossesb.jboss.com/xsd/jaxb-intros}XmlElementIntro" minOccurs="0"/>
- *         &lt;element ref="{http://jbossesb.jboss.com/xsd/jaxb-intros}XmlAttributeIntro" minOccurs="0"/>
+ *         &lt;element ref="{http://jbossesb.jboss.com/xsd/jaxb-intros}XmlElement" minOccurs="0"/>
+ *         &lt;element ref="{http://jbossesb.jboss.com/xsd/jaxb-intros}XmlAttribute" minOccurs="0"/>
  *       &lt;/sequence>
  *       &lt;attribute name="name" use="required" type="{http://www.w3.org/2001/XMLSchema}anySimpleType" />
  *     &lt;/restriction>
@@ -42,69 +42,69 @@
  */
 @XmlAccessorType(XmlAccessType.FIELD)
 @XmlType(name = "class-member-intro-config", propOrder = {
-    "xmlElementIntro",
-    "xmlAttributeIntro"
+    "xmlElement",
+    "xmlAttribute"
 })
 @XmlSeeAlso({
-    FieldIntroConfig.class,
-    MethodIntroConfig.class
+    MethodIntroConfig.class,
+    FieldIntroConfig.class
 })
 public class ClassMemberIntroConfig {
 
-    @XmlElement(name = "XmlElementIntro")
-    protected XmlElementIntro xmlElementIntro;
-    @XmlElement(name = "XmlAttributeIntro")
-    protected XmlAttributeIntro xmlAttributeIntro;
+    @XmlElement(name = "XmlElement")
+    protected XmlElementIntro xmlElement;
+    @XmlElement(name = "XmlAttribute")
+    protected XmlAttributeIntro xmlAttribute;
     @XmlAttribute(required = true)
     @XmlSchemaType(name = "anySimpleType")
     protected String name;
 
     /**
-     * Gets the value of the xmlElementIntro property.
+     * Gets the value of the xmlElement property.
      * 
      * @return
      *     possible object is
      *     {@link XmlElementIntro }
      *     
      */
-    public XmlElementIntro getXmlElementIntro() {
-        return xmlElementIntro;
+    public XmlElementIntro getXmlElement() {
+        return xmlElement;
     }
 
     /**
-     * Sets the value of the xmlElementIntro property.
+     * Sets the value of the xmlElement property.
      * 
      * @param value
      *     allowed object is
      *     {@link XmlElementIntro }
      *     
      */
-    public void setXmlElementIntro(XmlElementIntro value) {
-        this.xmlElementIntro = value;
+    public void setXmlElement(XmlElementIntro value) {
+        this.xmlElement = value;
     }
 
     /**
      * Gets the value of the xmlAttributeIntro property.
      * 
      * @return
      *     possible object is
      *     {@link XmlAttributeIntro }
      *     
      */
-    public XmlAttributeIntro getXmlAttributeIntro() {
-        return xmlAttributeIntro;
+    public XmlAttributeIntro getXmlAttribute() {
+        return xmlAttribute;
     }
 
     /**
      * Sets the value of the xmlAttributeIntro property.
      * 
      * @param value
      *     allowed object is
      *     {@link XmlAttributeIntro }
      *     
      */
-    public void setXmlAttributeIntro(XmlAttributeIntro value) {
-        this.xmlAttributeIntro = value;
+    public void setXmlAttribute(XmlAttributeIntro value) {
+        this.xmlAttribute = value;
     }
 
     /**
@@ -42,69 +42,69 @@
 
     /**
-     * Gets the value of the xmlAttributeIntro property.
+     * Gets the value of the xmlAttribute property.
      * 
      * @return
@@ -42,69 +42,69 @@
 
     /**
-     * Sets the value of the xmlAttributeIntro property.
+     * Sets the value of the xmlAttribute property.
      * 
      * @param value

Modified: labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/configmodel/FieldIntroConfig.java
===================================================================
--- labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/configmodel/FieldIntroConfig.java	2007-06-25 11:52:21 UTC (rev 12824)
+++ labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/configmodel/FieldIntroConfig.java	2007-06-25 13:24:38 UTC (rev 12825)
@@ -2,7 +2,7 @@
 // This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, v2.1.3-b01-fcs 
 // See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
 // Any modifications to this file will be lost upon recompilation of the source schema. 
-// Generated on: 2007.06.14 at 03:00:46 PM BST 
+// Generated on: 2007.06.25 at 01:32:14 PM BST 
 //
 
 
@@ -14,12 +14,12 @@
 
 
 /**
  * <p>Java class for anonymous complex type.
  * 
  * <p>The following schema fragment specifies the expected content contained within this class.
  * 
  * <pre>
- * &lt;complexType>
+ * &lt;complexType name="Field">
  *   &lt;complexContent>
  *     &lt;extension base="{http://jbossesb.jboss.com/xsd/jaxb-intros}class-member-intro-config">
  *     &lt;/extension>
@@ -30,7 +30,7 @@
  * 
  */
 @XmlAccessorType(XmlAccessType.FIELD)
- at XmlType(name = "")
+ at XmlType(name = "Field")
 public class FieldIntroConfig
     extends ClassMemberIntroConfig
 {
@@ -14,12 +14,12 @@
 
 /**
- * <p>Java class for anonymous complex type.
+ * <p>Java class for Field complex type.
  * 
  * <p>The following schema fragment specifies the expected content contained within this class.

Modified: labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/configmodel/JaxbIntros.java
===================================================================
--- labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/configmodel/JaxbIntros.java	2007-06-25 11:52:21 UTC (rev 12824)
+++ labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/configmodel/JaxbIntros.java	2007-06-25 13:24:38 UTC (rev 12825)
@@ -2,7 +2,7 @@
 // This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, v2.1.3-b01-fcs 
 // See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
 // Any modifications to this file will be lost upon recompilation of the source schema. 
-// Generated on: 2007.06.14 at 03:00:46 PM BST 
+// Generated on: 2007.06.25 at 01:32:14 PM BST 
 //
 
 
@@ -29,7 +29,7 @@
  *   &lt;complexContent>
  *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
  *       &lt;sequence>
- *         &lt;element ref="{http://jbossesb.jboss.com/xsd/jaxb-intros}class-intro-config" maxOccurs="unbounded"/>
+ *         &lt;element ref="{http://jbossesb.jboss.com/xsd/jaxb-intros}Class" maxOccurs="unbounded"/>
  *       &lt;/sequence>
  *       &lt;attribute name="default-namespace" type="{http://www.w3.org/2001/XMLSchema}anySimpleType" />
  *     &lt;/restriction>
@@ -41,30 +41,30 @@
  */
 @XmlAccessorType(XmlAccessType.FIELD)
 @XmlType(name = "", propOrder = {
-    "classIntroConfig"
+    "clazz"
 })
 @XmlRootElement(name = "jaxb-intros")
 public class JaxbIntros {
 
-    @XmlElement(name = "class-intro-config", required = true)
-    protected List<ClassIntroConfig> classIntroConfig;
+    @XmlElement(name = "Class", required = true)
+    protected List<ClassIntroConfig> clazz;
     @XmlAttribute(name = "default-namespace")
     @XmlSchemaType(name = "anySimpleType")
     protected String defaultNamespace;
 
     /**
      * Gets the value of the classIntroConfig property.
      * 
      * <p>
      * This accessor method returns a reference to the live list,
      * not a snapshot. Therefore any modification you make to the
      * returned list will be present inside the JAXB object.
      * This is why there is not a <CODE>set</CODE> method for the classIntroConfig property.
      * 
      * <p>
      * For example, to add a new item, do as follows:
      * <pre>
-     *    getClassIntroConfig().add(newItem);
+     *    getClazz().add(newItem);
      * </pre>
      * 
      * 
@@ -74,11 +74,11 @@
      * 
      * 
      */
-    public List<ClassIntroConfig> getClassIntroConfig() {
-        if (classIntroConfig == null) {
-            classIntroConfig = new ArrayList<ClassIntroConfig>();
+    public List<ClassIntroConfig> getClazz() {
+        if (clazz == null) {
+            clazz = new ArrayList<ClassIntroConfig>();
         }
-        return this.classIntroConfig;
+        return this.clazz;
     }
 
     /**
@@ -41,30 +41,30 @@
 
     /**
-     * Gets the value of the classIntroConfig property.
+     * Gets the value of the clazz property.
      * 
      * <p>
@@ -41,30 +41,30 @@
      * not a snapshot. Therefore any modification you make to the
      * returned list will be present inside the JAXB object.
-     * This is why there is not a <CODE>set</CODE> method for the classIntroConfig property.
+     * This is why there is not a <CODE>set</CODE> method for the clazz property.
      * 
      * <p>

Modified: labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/configmodel/MethodIntroConfig.java
===================================================================
--- labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/configmodel/MethodIntroConfig.java	2007-06-25 11:52:21 UTC (rev 12824)
+++ labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/configmodel/MethodIntroConfig.java	2007-06-25 13:24:38 UTC (rev 12825)
@@ -2,7 +2,7 @@
 // This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, v2.1.3-b01-fcs 
 // See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
 // Any modifications to this file will be lost upon recompilation of the source schema. 
-// Generated on: 2007.06.14 at 03:00:46 PM BST 
+// Generated on: 2007.06.25 at 01:32:14 PM BST 
 //
 
 
@@ -14,12 +14,12 @@
 
 
 /**
  * <p>Java class for anonymous complex type.
  * 
  * <p>The following schema fragment specifies the expected content contained within this class.
  * 
  * <pre>
- * &lt;complexType>
+ * &lt;complexType name="Method">
  *   &lt;complexContent>
  *     &lt;extension base="{http://jbossesb.jboss.com/xsd/jaxb-intros}class-member-intro-config">
  *     &lt;/extension>
@@ -30,7 +30,7 @@
  * 
  */
 @XmlAccessorType(XmlAccessType.FIELD)
- at XmlType(name = "")
+ at XmlType(name = "Method")
 public class MethodIntroConfig
     extends ClassMemberIntroConfig
 {
@@ -14,12 +14,12 @@
 
 /**
- * <p>Java class for anonymous complex type.
+ * <p>Java class for Method complex type.
  * 
  * <p>The following schema fragment specifies the expected content contained within this class.

Modified: labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/configmodel/ObjectFactory.java
===================================================================
--- labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/configmodel/XmlAttributeIntro.java	2007-06-25 11:52:21 UTC (rev 12824)
+++ labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/configmodel/XmlAttributeIntro.java	2007-06-25 13:24:38 UTC (rev 12825)
@@ -2,7 +2,7 @@
 // This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, v2.1.3-b01-fcs 
 // See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
 // Any modifications to this file will be lost upon recompilation of the source schema. 
-// Generated on: 2007.06.14 at 03:00:46 PM BST 
+// Generated on: 2007.06.25 at 01:32:14 PM BST 
 //
 
 
@@ -11,18 +11,17 @@
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlAttribute;
-import javax.xml.bind.annotation.XmlRootElement;
 import javax.xml.bind.annotation.XmlSchemaType;
 import javax.xml.bind.annotation.XmlType;
 
 
 /**
  * <p>Java class for anonymous complex type.
  * 
  * <p>The following schema fragment specifies the expected content contained within this class.
  * 
  * <pre>
- * &lt;complexType>
+ * &lt;complexType name="XmlAttribute">
  *   &lt;complexContent>
  *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
  *       &lt;attribute name="name" type="{http://www.w3.org/2001/XMLSchema}anySimpleType" default="##default" />
@@ -36,8 +35,7 @@
  * 
  */
 @XmlAccessorType(XmlAccessType.FIELD)
- at XmlType(name = "")
- at XmlRootElement(name = "XmlAttributeIntro")
+ at XmlType(name = "XmlAttribute")
 public class XmlAttributeIntro {
 
     @XmlAttribute
@@ -11,18 +11,17 @@
 
 /**
- * <p>Java class for anonymous complex type.
+ * <p>Java class for XmlAttribute complex type.
  * 
  * <p>The following schema fragment specifies the expected content contained within this class.

Modified: labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/configmodel/XmlElementIntro.java
===================================================================
--- labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/configmodel/XmlElementIntro.java	2007-06-25 11:52:21 UTC (rev 12824)
+++ labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/configmodel/XmlElementIntro.java	2007-06-25 13:24:38 UTC (rev 12825)
@@ -2,7 +2,7 @@
 // This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, v2.1.3-b01-fcs 
 // See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
 // Any modifications to this file will be lost upon recompilation of the source schema. 
-// Generated on: 2007.06.14 at 03:00:46 PM BST 
+// Generated on: 2007.06.25 at 01:32:14 PM BST 
 //
 
 
@@ -11,18 +11,17 @@
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlAttribute;
-import javax.xml.bind.annotation.XmlRootElement;
 import javax.xml.bind.annotation.XmlSchemaType;
 import javax.xml.bind.annotation.XmlType;
 
 
 /**
  * <p>Java class for anonymous complex type.
  * 
  * <p>The following schema fragment specifies the expected content contained within this class.
  * 
  * <pre>
- * &lt;complexType>
+ * &lt;complexType name="XmlElement">
  *   &lt;complexContent>
  *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
  *       &lt;attribute name="name" type="{http://www.w3.org/2001/XMLSchema}anySimpleType" default="##default" />
@@ -39,8 +38,7 @@
  * 
  */
 @XmlAccessorType(XmlAccessType.FIELD)
- at XmlType(name = "")
- at XmlRootElement(name = "XmlElementIntro")
+ at XmlType(name = "XmlElement")
 public class XmlElementIntro {
 
     @XmlAttribute
@@ -11,18 +11,17 @@
 
 /**
- * <p>Java class for anonymous complex type.
+ * <p>Java class for XmlElement complex type.
  * 
  * <p>The following schema fragment specifies the expected content contained within this class.

Modified: labs/jbossesb/trunk/product/services/soap/src/main/java/org/jboss/soa/esb/actions/soap/jaxbintro/configmodel/XmlTypeIntro.java
===================================================================